SKILL API
=========
A library of SKILL functions and classes.

Packages:

- List
- String (Str)
- Geometry (Geo)
- Testing Framework (Test)

References
----------

- `Language Manuals <https://support.cadence.com/apex/Coveo_ProductManuals#t=ProductManualsFromRelease&ph=IC%206.1.8&cadrelease=ic618&seetocfiles=true>`_
- `Language Reference <https://support.cadence.com/apex/techpubDocViewerPage?path=sklangref/sklangrefIC6.1.8/sklangrefTOC.html>`_
- `Language User Guide <https://support.cadence.com/apex/techpubDocViewerPage?path=sklanguser/sklanguserIC6.1.8/sklanguserTOC.html>`_
- `Development Reference <https://support.cadence.com/apex/techpubDocViewerPage?path=skdevref/skdevrefIC6.1.8/skdevrefTOC.html>`_
- `IDE User Guide <https://support.cadence.com/apex/techpubDocViewerPage?path=skillide/skillideIC6.1.8/skillideTOC.html>`_

.. include:: List.rst

.. include:: Str.rst

.. include:: Geo.rst
